@@ -3,6 +3,45 @@ from numba import njit
 from scipy import stats
 
 
+# convert bnlearn format to my format
+def from_bnlearn(dag):
+    dag = dag[1: len(dag) - 1]
+    output = {}
+    for node in dag.split(']['):
+        if '|' not in node:
+            output[node] = {'par': [], 'nei': []}
+        else:
+            output[node.split('|')[0]] = {'par': node.split('|')[1].split(':'), 'nei': []}
+    return output
+
+
+def score(dag, data, score_function='bic', alpha=0.3):
+    if type(dag) is str:
+        dag = from_bnlearn(dag)
+    elif type(dag) is not dict:
+        raise Exception('The format of input true DAG is invalid.')
+    varnames = list(data)
+    if all(data[var].dtype.name == 'category' for var in data):
+        data = data.apply(lambda x: x.cat.codes).to_numpy()
+    elif all(data[var].dtype.name != 'category' for var in data):
+        data = data.to_numpy()
+    else:
+        raise Exception('Mixed data is not supported.')
+
+    sco = 0
+    for var in varnames:
+        cols = [varnames.index(v) for v in [var] + dag[var]['par']]
+        if score_function in ['nal', 'nal_g']:
+            sco += globals()[score_function](data, np.asarray(cols), alpha)
+        else:
+            try:
+                sco += globals()[score_function](data, np.asarray(cols))
+            except Exception as e:
+                raise Exception('score function ' + str(
+                    e) + ' is undefined or does not fit to data type. Available score functions are: bic (BIC for discrete variables) and nal (NAL for discrete variables).')
+    return sco
+
+
 def bic(data, cols, weight=None):
     arities = np.amax(data, axis=0) + 1
     return bic_counter(data, arities, cols, weight)
@@ -34,8 +73,8 @@ def bic_counter(data, arities, cols, weight=None):
     bic = 0
     for i in range(stride):
         if N_ijk[i] != 0:
-            bic += N_ijk[i] * np.log10(N_ijk[i] / N_ij[i])
-    bic -= 0.5 * np.log10(data.shape[0]) * (arities[cols[0]] - 1) * strides[0]
+            bic += N_ijk[i] * np.log(N_ijk[i] / N_ij[i])
+    bic -= 0.5 * np.log(data.shape[0]) * (arities[cols[0]] - 1) * strides[0]
     return bic
 
 
@@ -175,4 +214,4 @@ def local_score(data, cols, score_function='default', weights=None, alpha=0.3):
             except Exception as e:
                 raise Exception('score function ' + str(
                     e) + ' is undefined or does not fit to data type. Available score functions are: bic (BIC for discrete variables) and nal (NAL for discrete variables).')
-        return ls
\ No newline at end of file
+        return ls
